@@ -13,7 +13,7 @@ from . import parameters
 from . import decorators
 from . import metaflow_version
 from . import namespace
-from .util import resolve_identity, decompress_list
+from .util import resolve_identity, decompress_list, write_latest_run_id, get_latest_run_id
 from .task import MetaflowTask
 from .exception import CommandException, MetaflowException
 from .graph import FlowGraph
@@ -25,7 +25,6 @@ from .metadata import METADATAPROVIDERS
 from .plugins import ENVIRONMENTS
 from .environment import MetaflowEnvironment
 from .pylint_wrapper import PyLint
-from .metaflow_config import DATASTORE_SYSROOT_LOCAL
 from .event_logger import EventLogger
 from .monitor import Monitor
 
@@ -162,7 +161,9 @@ def output_dot(obj):
     echo_always(obj.graph.output_dot(), err=False)
 
 
-@cli.command(help='Get data artifacts of a task.')
+@cli.command(help='Get data artifacts of a task or all tasks in a step. '
+                  'The format for input-path is either <run_id>/<step_name> or '
+                  '<run_id>/<step_name>/<task_id>.')
 @click.argument('input-path')
 @click.option('--private/--no-private',
               default=False,
@@ -195,6 +196,14 @@ def dump(obj,
               'max_value_size': max_value_size,
               'include': {t for t in include.split(',') if t}}
 
+    if obj.datastore.datastore_root is None:
+        obj.datastore.datastore_root = obj.datastore.get_datastore_root_from_config(
+            obj.echo, create_on_absent=False)
+    if obj.datastore.datastore_root is None:
+        raise CommandException(
+            "Could not find the location of the datastore -- did you correctly set the "
+            "METAFLOW_DATASTORE_SYSROOT_%s environment variable" % (obj.datastore.TYPE).upper())
+
     # Pathspec can either be run_id/step_name or run_id/step_name/task_id.
     parts = input_path.split('/')
     if len(parts) == 2:
@@ -207,6 +216,7 @@ def dump(obj,
                                "or run_id/step_name/task_id")
 
     from metaflow.datastore.datastore_set import MetaflowDatastoreSet
+
     datastore_set = MetaflowDatastoreSet(
                         obj.datastore,
                         obj.flow.name,
@@ -242,7 +252,9 @@ def dump(obj,
         echo('Artifacts written to *%s*' % file)
 
 
-@cli.command(help='Show stdout/stderr produced by a task.')
+@cli.command(help='Show stdout/stderr produced by a task or all tasks in a step. '
+                  'The format for input-path is either <run_id>/<step_name> or '
+                  '<run_id>/<step_name>/<task_id>.')
 @click.argument('input-path')
 @click.option('--stdout/--no-stdout',
               default=False,
@@ -279,6 +291,14 @@ def logs(obj, input_path, stdout=None, stderr=None, both=None):
         raise CommandException("input_path should either be run_id/step_name"
                                "or run_id/step_name/task_id")
 
+    if obj.datastore.datastore_root is None:
+        obj.datastore.datastore_root = obj.datastore.get_datastore_root_from_config(
+            obj.echo, create_on_absent=False)
+    if obj.datastore.datastore_root is None:
+        raise CommandException(
+            "Could not find the location of the datastore -- did you correctly set the "
+            "METAFLOW_DATASTORE_SYSROOT_%s environment variable" % (obj.datastore.TYPE).upper())
+
     from metaflow.datastore.datastore_set import MetaflowDatastoreSet
     datastore_set = MetaflowDatastoreSet(
                         obj.datastore,
@@ -380,6 +400,9 @@ def step(obj,
          fg='magenta',
          bold=False)
 
+    if obj.datastore.datastore_root is None:
+        obj.datastore.datastore_root = obj.datastore.get_datastore_root_from_config(obj.echo)
+
     obj.metadata.add_sticky_tags(tags=tags)
     paths = decompress_list(input_paths) if input_paths else []
 
@@ -426,6 +449,10 @@ def init(obj, run_id=None, task_id=None, **kwargs):
     # user-specified parameters and our internal options. Note that
     # user-specified parameters are often defined as environment
     # variables.
+
+    if obj.datastore.datastore_root is None:
+        obj.datastore.datastore_root = obj.datastore.get_datastore_root_from_config(obj.echo)
+
     runtime = NativeRuntime(obj.flow,
                             obj.graph,
                             obj.datastore,
@@ -503,13 +530,9 @@ def resume(obj,
     before_run(obj, tags, decospecs + obj.environment.decospecs())
 
     if origin_run_id is None:
-        path = os.path.join(DATASTORE_SYSROOT_LOCAL, 'latest_run')
-        if os.path.exists(path):
-            with open(path) as f:
-                origin_run_id = f.read()
-        else:
-            raise CommandException("A previous run id was not found. "
-                                   "Specify --origin-run-id.")
+        origin_run_id = get_latest_run_id(obj.echo, obj.flow.name)
+        if origin_run_id is None:
+            raise CommandException("A previous run id was not found. Specify --origin-run-id.")
 
     if step_to_rerun is None:
         clone_steps = set()
@@ -531,7 +554,6 @@ def resume(obj,
                             max_workers=max_workers,
                             max_num_splits=max_num_splits,
                             max_log_size=max_log_size * 1024 * 1024)
-
     runtime.persist_parameters()
     runtime.execute()
 
@@ -578,7 +600,7 @@ def run(obj,
                             max_workers=max_workers,
                             max_num_splits=max_num_splits,
                             max_log_size=max_log_size * 1024 * 1024)
-    write_latest_run_id(runtime.run_id)
+    write_latest_run_id(obj, runtime.run_id)
     write_run_id(run_id_file, runtime.run_id)
 
     parameters.set_parameters(obj.flow, kwargs)
@@ -586,18 +608,6 @@ def run(obj,
     runtime.execute()
 
 
-def write_latest_run_id(run_id):
-    try:
-        os.makedirs(DATASTORE_SYSROOT_LOCAL)
-    except OSError as x:
-        if x.errno != 17:
-            # already exists is ok
-            raise
-    path = os.path.join(DATASTORE_SYSROOT_LOCAL, 'latest_run')
-    with open(path, 'w') as f:
-        f.write(str(run_id))
-
-
 def write_run_id(run_id_file, run_id):
     if run_id_file is not None:
         with open(run_id_file, 'w') as f:
@@ -617,10 +627,14 @@ def before_run(obj, tags, decospecs):
     if decospecs:
         decorators._attach_decorators(obj.flow, decospecs)
         obj.graph = FlowGraph(obj.flow.__class__)
+    obj.check(obj.graph, obj.flow, obj.environment, pylint=obj.pylint)
     #obj.environment.init_environment(obj.logger)
+
+    if obj.datastore.datastore_root is None:
+        obj.datastore.datastore_root = obj.datastore.get_datastore_root_from_config(obj.echo)
+
     decorators._init_decorators(
         obj.flow, obj.graph, obj.environment, obj.datastore, obj.logger)
-    obj.check(obj.graph, obj.flow, obj.environment, pylint=obj.pylint)
     obj.metadata.add_sticky_tags(tags=tags)
 
     # Package working directory only once per run.
@@ -750,10 +764,7 @@ def start(ctx,
                                                   ctx.obj.event_logger,
                                                   ctx.obj.monitor)
     ctx.obj.datastore = DATASTORES[datastore]
-    if datastore_root is None:
-        datastore_root = ctx.obj.datastore.get_datastore_root_from_config()
-    ctx.obj.datastore.datastore_root = datastore_root
-
+    ctx.obj.datastore_root = datastore_root
     if ctx.invoked_subcommand not in ('run', 'resume'):
         # run/resume are special cases because they can add more decorators with --with,
         # so they have to take care of themselves.
@@ -823,9 +834,13 @@ class CliState(object):
         self.flow = flow
 
 def main(flow, args=None, handle_exceptions=True, entrypoint=None):
-
+    # Ignore warning(s) and prevent spamming the end-user.
+    # TODO: This serves as a short term workaround for RuntimeWarning(s) thrown
+    # in py3.8 related to log buffering (bufsize=1).
+    import warnings
+    warnings.filterwarnings('ignore')
     if entrypoint is None:
-        entrypoint = [sys.executable, sys.argv[0]]
+        entrypoint = [sys.executable, '-u', sys.argv[0]]
 
     state = CliState(flow)
     state.entrypoint = entrypoint
