@@ -47,20 +47,38 @@ def metadata(ms):
     Parameters
     ----------
     ms : string
-        Can be one of 'local' or any of the metadata plugins defined
+        Can be a path (selects local metadata), a URL starting with http (selects
+        the service metadata at that URL) or explicitly <metadata>@<info> for example
+        local@<path> or service@<url>
     """
     global current_metadata
-    res = [m for m in METADATAPROVIDERS if m.TYPE == ms]
-    if res:
-        current_metadata = res[0]
+    infos = ms.split('@', maxsplit=1)
+    types = [m.TYPE for m in METADATAPROVIDERS]
+    if infos[0] in types:
+        current_metadata = [m for m in METADATAPROVIDERS if m.TYPE == infos[0]][0]
+        if len(infos) > 1:
+            current_metadata.INFO = infos[1]
     else:
-        print("Unknown metadata service: %s" % str(ms))
+        # Deduce from ms; if starts with http, use service or else use local
+        if ms.startswith('http'):
+            metadata_type = 'service'
+        else:
+            metadata_type = 'local'
+        res = [m for m in METADATAPROVIDERS if m.TYPE == metadata_type]
+        if not res:
+            print(
+                "Cannot find a '%s' metadata provider -- "
+                "try specifying one explicitly using <type>@<info>", metadata_type)
+            return get_metadata()
+        current_metadata = res[0]
+        current_metadata.INFO = ms
+    return get_metadata()
 
 
 def get_metadata():
     if current_metadata is False:
         default_metadata()
-    return current_metadata.TYPE
+    return '%s@%s' % (current_metadata.TYPE, current_metadata.INFO)
 
 
 def default_metadata():
@@ -134,9 +152,17 @@ class Metaflow(object):
         Returns:
         iterator: Iterator over `Flow` objects
         """
+        # We do not filter on namespace in the request because
+        # filtering on namespace on flows means finding at least one
+        # run in this namespace. This is_in_namespace() function
+        # does this properly in this case
         all_flows = self.metadata.get_object('root', 'flow')
         for flow in all_flows:
-            yield flow
+            try:
+                v = Flow(_object=flow)
+                yield v
+            except MetaflowNamespaceMismatch:
+                continue
 
     def __str__(self):
         return 'Metaflow()'
@@ -231,7 +257,7 @@ class MetaflowObject(object):
             self._NAME, self._CHILD_CLASS._NAME, query_filter, *self.path_components)
 
         children = filter(
-            lambda x: x.is_in_namespace() and self._iter_filter(x),
+            lambda x: self._iter_filter(x),
             (self._CHILD_CLASS(_object=obj, _parent=self, _namespace_check=False)
                 for obj in unfiltered_children))
 
