@@ -191,7 +191,7 @@ class MetaflowDataStore(object):
         return os.path.join(self.root, filename)
 
     @classmethod
-    def get_datastore_root_from_config(cls):
+    def get_datastore_root_from_config(cls, echo, create_on_absent=True):
         """
         Returns a default choice for datastore_root from metaflow_config
         depending on the datastore type.
