@@ -14,7 +14,7 @@ if sys.platform == "darwin":
 
 def init_config():
     # Read configuration from $METAFLOW_HOME/<profile>.conf.
-    home = os.environ.get('METAFLOW_HOME', '~/.metaflow')
+    home = os.environ.get('METAFLOW_HOME', '~/.metaflowconfig')
     profile = os.environ.get('METAFLOW_PROFILE')
     path_to_config = os.path.join(home, 'config.json')
     if profile:
@@ -23,10 +23,10 @@ def init_config():
     config = {}
     if os.path.exists(path_to_config):
         with open(path_to_config) as f:
-            config = json.load(f)
+            return json.load(f)
     elif profile:
-        raise MetaflowException('Could not find profile \'%s\' (expecting it at \'%s\')' %
-                                (profile, path_to_config))
+        raise MetaflowException('Unable to locate METAFLOW_PROFILE \'%s\' in \'%s\')' %
+                                (profile, home))
     return config
 
 
@@ -34,6 +34,16 @@ def init_config():
 METAFLOW_CONFIG = init_config()
 
 
+def update_var(name, value):
+    import metaflow.metaflow_config as conf
+    vars(conf)[name] = value
+
+
+def get_var(name):
+    import metaflow.metaflow_config as conf
+    return vars(conf).get(name)
+
+
 def from_env(name, default=None, is_path=False):
     result = os.environ.get(name, METAFLOW_CONFIG.get(name, default))
     if result and is_path:
@@ -46,12 +56,22 @@ def from_env(name, default=None, is_path=False):
 ###
 # Path to the local directory to store artifacts for 'local' datastore.
 # Also used for tracking 'local' metadata.
-DATASTORE_SYSROOT_LOCAL = from_env('METAFLOW_DATASTORE_SYSROOT_LOCAL', '.metaflow', is_path=True)
+# The actual directory used will be (in order of precedence)
+#  - Anything specified with --datastore-root
+#  - Anything specified in METAFLOW_DATASTORE_SYSROOT_LOCAL
+#  - A directory named DATASTORE_LOCAL_DIR anywhere in the current path
+#    (starting at the current directory and going up the tree)
+#  - If nothing is found with the two previous rules, a DATASTORE_LOCAL_DIR
+#    will be created in the local directory
+DATASTORE_LOCAL_DIR = '.metaflow'
+DATASTORE_SYSROOT_LOCAL = from_env('METAFLOW_DATASTORE_SYSROOT_LOCAL', is_path=True)
 # S3 bucket and prefix to store artifacts for 's3' datastore.
-DATASTORE_SYSROOT_S3 = from_env('METAFLOW_DATASTORE_SYSROOT_S3', is_path=True)
+DATASTORE_SYSROOT_S3 = '%s/userdata' % from_env('METAFLOW_DATASTORE_SYSROOT_S3', is_path=True)
 # S3 datatools root location
 DATATOOLS_S3ROOT = from_env(
-    'METAFLOW_DATATOOLS_S3ROOT', '%s/data' % DATASTORE_SYSROOT_S3, is_path=True)
+    'METAFLOW_DATATOOLS_S3ROOT', 
+        '%s/data' % from_env('METAFLOW_DATASTORE_SYSROOT_S3', is_path=True),
+         is_path=True)
 
 ###
 # Datastore local cache (for client access to artifacts)
@@ -64,9 +84,10 @@ CLIENT_CACHE_MAX_SIZE = from_env('METAFLOW_CLIENT_CACHE_MAX_SIZE', 10000)
 ###
 # Metadata configuration
 ###
-METADATA_SERVICE_URL = from_env('METAFLOW_SERVICE_ENDPOINT_URL', is_path=True)
+# WARNING: This variable should not be imported but accessed using get_var
+METADATA_SERVICE_URL = from_env('METAFLOW_SERVICE_URL', is_path=True)
 METADATA_SERVICE_NUM_RETRIES = from_env('METAFLOW_SERVICE_RETRY_COUNT', 5)
-METADATA_SERVICE_HEADERS = from_env('METAFLOW_SERVICE_HEADERS', {})
+METADATA_SERVICE_HEADERS = json.loads(from_env('METAFLOW_SERVICE_HEADERS', '{}'))
 
 
 ###
@@ -76,13 +97,19 @@ METADATA_SERVICE_HEADERS = from_env('METAFLOW_SERVICE_HEADERS', {})
 ECS_S3_ACCESS_IAM_ROLE = from_env('METAFLOW_ECS_S3_ACCESS_IAM_ROLE')
 # Job queue for AWS Batch
 BATCH_JOB_QUEUE = from_env('METAFLOW_BATCH_JOB_QUEUE')
+# Default container image for AWS Batch
+BATCH_CONTAINER_IMAGE = from_env("METAFLOW_BATCH_CONTAINER_IMAGE")
+# Metadata service URL for AWS Batch
+BATCH_METADATA_SERVICE_URL = METADATA_SERVICE_URL
 
 ###
 # Conda plugin configuration
 ###
 # Conda package root location on S3
 CONDA_PACKAGE_S3ROOT = from_env(
-    'METAFLOW_CONDA_PACKAGE_S3ROOT', '%s/conda' % DATASTORE_SYSROOT_S3, is_path=True)
+    'METAFLOW_CONDA_PACKAGE_S3ROOT', 
+        '%s/conda' % from_env('METAFLOW_DATASTORE_SYSROOT_S3', is_path=True), 
+        is_path=True)
 
 ###
 # Debug configuration
@@ -98,15 +125,22 @@ for typ in DEBUG_OPTIONS:
 # Boolean flag for metaflow AWS sandbox access
 AWS_SANDBOX_ENABLED = bool(from_env('METAFLOW_AWS_SANDBOX_ENABLED', False))
 # Metaflow AWS sandbox auth endpoint
-AWS_SANDBOX_STS_ENDPOINT_URL = from_env('METAFLOW_AWS_SANDBOX_STS_ENDPOINT_URL', is_path=True)
-# Metaflow AWS sandbox IAM role
-AWS_SANDBOX_IAM_ROLE = from_env('METAFLOW_AWS_SANDBOX_IAM_ROLE')
+AWS_SANDBOX_STS_ENDPOINT_URL = from_env('METAFLOW_SERVICE_URL', is_path=True)
 # Metaflow AWS sandbox API auth key
 AWS_SANDBOX_API_KEY = from_env('METAFLOW_AWS_SANDBOX_API_KEY')
+# Internal Metadata URL
+AWS_SANDBOX_INTERNAL_SERVICE_URL = from_env('METAFLOW_AWS_SANDBOX_INTERNAL_SERVICE_URL', is_path=True)
+# AWS region
+AWS_SANDBOX_REGION = from_env('METAFLOW_AWS_SANDBOX_REGION')
 
+
+# Finalize configuration
 if AWS_SANDBOX_ENABLED:
-    METADATA_SERVICE_URL = '%s/api' % AWS_SANDBOX_STS_ENDPOINT_URL
-    METADATA_SERVICE_HEADERS = {'x-api-key': AWS_SANDBOX_API_KEY}
+    os.environ['AWS_DEFAULT_REGION'] = AWS_SANDBOX_REGION
+    BATCH_METADATA_SERVICE_URL = AWS_SANDBOX_INTERNAL_SERVICE_URL
+    METADATA_SERVICE_HEADERS['x-api-key'] = AWS_SANDBOX_API_KEY
+
+
 # MAX_ATTEMPTS is the maximum number of attempts, including the first
 # task, retries, and the final fallback task and its retries.
 #
@@ -149,45 +183,28 @@ def get_pinned_conda_libs():
 
 cached_aws_sandbox_creds = None
 
-
-def get_authenticated_boto3_session():
+def get_authenticated_boto3_client(module):
     from metaflow.exception import MetaflowException
     import requests
-    import json
-    import socket
     try:
-        from boto3.session import Session
+        import boto3
     except (NameError, ImportError):
         raise MetaflowException(
             "Could not import module 'boto3'. Install boto3 first.")
 
-    if sys.platform != 'darwin':
-        try:
-            requests.get('http://169.254.169.254', timeout=0.1)
-            return Session()
-        except (socket.timeout,
-                requests.exceptions.ConnectTimeout,
-                requests.exceptions.ReadTimeout,
-                requests.exceptions.ConnectionError):
-            pass
-
     if AWS_SANDBOX_ENABLED:
         global cached_aws_sandbox_creds
         if cached_aws_sandbox_creds is None:
             # authenticate using STS
-            url = "%s/api/auth/role/token" % AWS_SANDBOX_STS_ENDPOINT_URL
+            url = "%s/auth/token" % AWS_SANDBOX_STS_ENDPOINT_URL
             headers = {
-                'Content-Type': 'text/plain',
                 'x-api-key': AWS_SANDBOX_API_KEY
             }
-            data = {
-                "role_arn": AWS_SANDBOX_IAM_ROLE
-            }
             try:
-                r = requests.post(url, data=json.dumps(data), headers=headers)
+                r = requests.get(url, headers=headers)
                 r.raise_for_status()
-                cached_aws_sandbox_creds = json.loads(r.text)
+                cached_aws_sandbox_creds = r.json()
             except requests.exceptions.HTTPError as e:
                 raise MetaflowException(repr(e))
-        return Session(**cached_aws_sandbox_creds)
-    return Session()
+        return boto3.session.Session(**cached_aws_sandbox_creds).client(module)
+    return boto3.client(module)
