@@ -3,17 +3,15 @@ import os
 import json
 import fcntl
 
-from metaflow.metaflow_config import DATASTORE_SYSROOT_LOCAL
-
 CONDA_MAGIC_FILE = 'conda.cnd'
 
 
-def get_conda_manifest_path():
-    return os.path.join(DATASTORE_SYSROOT_LOCAL, CONDA_MAGIC_FILE)
+def get_conda_manifest_path(ds_root):
+    return os.path.join(ds_root, CONDA_MAGIC_FILE)
 
 
-def read_conda_manifest():
-    path = get_conda_manifest_path()
+def read_conda_manifest(ds_root):
+    path = get_conda_manifest_path(ds_root)
     if os.path.exists(path) and os.path.getsize(path) > 0:
         with open(path) as f:
             return json.load(f)
@@ -21,8 +19,8 @@ def read_conda_manifest():
         return {}
 
 
-def write_to_conda_manifest(key, value):
-    path = get_conda_manifest_path()
+def write_to_conda_manifest(ds_root, key, value):
+    path = get_conda_manifest_path(ds_root)
     try:
         os.makedirs(os.path.dirname(path))
     except OSError as x:
