@@ -24,11 +24,11 @@ def conda(obj):
 def resolve(obj,
             step_to_resolve=None,
             force=False):
-   obj.environment.init_environment(obj.logger)
-   for step in obj.flow:
-       if step_to_resolve is None or step.__name__ == step_to_resolve:
-           for deco in step.decorators:
-               if deco.name == "conda":
-                   obj.echo("Resolving for step %s.." % step.__name__, fg='yellow', bold=False)
-                   env_id = deco._resolve_step_environment(force)
-                   obj.echo("Using/Generated Conda environment %s" % (env_id), fg='yellow', indent=True, bold=False)
\ No newline at end of file
+    obj.environment.init_environment(obj.logger)
+    for step in obj.flow:
+        if step_to_resolve is None or step.__name__ == step_to_resolve:
+            for deco in step.decorators:
+                if deco.name == "conda":
+                    obj.echo("Resolving for step %s.." % step.__name__, fg='yellow', bold=False)
+                    env_id = deco._resolve_step_environment(obj.datastore.datastore_root, force=force)
+                    obj.echo("Using/Generated Conda environment %s" % (env_id), fg='yellow', indent=True, bold=False)
\ No newline at end of file
