@@ -110,6 +110,8 @@ class NativeRuntime(object):
             # (see PREFETCH_DATA_ARTIFACTS) so that the entire runtime can
             # access the relevant data from cache (instead of going to the datastore
             # after the first prefetch).
+            logger(
+                'Gathering required information to resume run (this may take a bit of time)...')
             self._origin_ds_set = \
                 MetaflowDatastoreSet(
                     datastore,
@@ -119,7 +121,6 @@ class NativeRuntime(object):
                     event_logger=event_logger,
                     monitor=monitor,
                     prefetch_data_artifacts=PREFETCH_DATA_ARTIFACTS)
-
         self._run_queue = []
         self._poll = procpoll.make_poll()
         self._workers = {}  # fd -> subprocess mapping
@@ -368,7 +369,16 @@ class NativeRuntime(object):
                 worker = self._workers.get(event.fd)
                 if worker:
                     if event.can_read:
-                        worker.read_logline(event.fd)
+                        # Try to read as many loglines as possible within reason. The reason we
+                        # read more than one is to attempt to avoid interleaving lines from
+                        # stdout and stderr. If a process writes to both stdout and stderr,
+                        # reading only one line at a time will almost guarantee some form of 
+                        # mingling which can be confusing to the user. There is clearly
+                        # no guarantee of course but this seems to improve output for
+                        # confusing use cases
+                        max_lines = 64
+                        while max_lines > 0 and worker.read_logline(event.fd):
+                            max_lines -= 1
                     if event.is_terminated:
                         returncode = worker.terminate()
 
@@ -527,6 +537,7 @@ class Task(object):
             prefix = '[%s] ' % self._path
 
         self._logger(msg, head=prefix, system_msg=system_msg)
+        sys.stdout.flush()
 
     def _find_origin_task(self, clone_run_id, join_type):
         if self.step == '_parameters':
