@@ -158,6 +158,35 @@ def resolve_identity():
         raise MetaflowUnknownUser()
 
 
+def get_latest_run_id(echo, flow_name):
+    from metaflow.datastore.local import LocalDataStore
+    local_root = LocalDataStore.datastore_root
+    if local_root is None:
+        v = LocalDataStore.get_datastore_root_from_config(echo, create_on_absent=False)
+        LocalDataStore.datastore_root = local_root = v
+    if local_root:
+        path = os.path.join(local_root, flow_name, 'latest_run')
+        if os.path.exists(path):
+            with open(path) as f:
+                return f.read()
+    return None
+
+
+def write_latest_run_id(obj, run_id):
+    from metaflow.datastore.local import LocalDataStore
+    if LocalDataStore.datastore_root is None:
+        LocalDataStore.datastore_root = LocalDataStore.get_datastore_root_from_config(obj.echo)
+    path = os.path.join(LocalDataStore.datastore_root, obj.flow.name)
+    try:
+        os.makedirs(path)
+    except OSError as x:
+        if x.errno != 17:
+            # Directories exists in other casewhich is fine
+            raise
+    with open(os.path.join(path, 'latest_run'), 'w') as f:
+        f.write(str(run_id))
+
+
 def get_object_package_version(obj):
     """    
     Return the top level package name and package version that defines the
